#ifndef __i815_CHIPSET_REGS_
#define __i815_CHIPSET_REGS_

/*
	Based on INTEL 82815 GMCH DATASHEET (June 2000)
	Document Reference Number 290688-001


	------------

	15/1/2001
	v1


*/


#define i815_ID 0x011308086

#define CONF_ADDR 0x0CF8
#define CONF_DATA 0x0CFC

#define CFGE 0x080000000



/* 
	------------------- registers
*/

#define _RID 8

#define _AGPSTAT 0x0A4

#define _AGPCTRL 0x0B0  
/*
 AGPCTRL register (Page 76)
 bit 0 : AGP 4X Override
 if set, AGPSTAT bit 2 (AGP 4X) will be always read
 as 0 (so disabled)
*/

#define _AGPCMD	0x0A8
/*
 AGPCMD register (Page 75)
 bit 4 : fastwrite enable
 bit 9 : sideband addressing
*/

#define _SMRAM   0x070
/*
 SMRAM 0x70 (Page 62)
 MISCC 0x72  (so>>16) (Page 64)
 bit 1  : BNR, Block New Request Lookahead
 bit 11 : CPC, Command per clock mask enable
 bit 13 : SM bypass
	 0 : bypass if 100 Mhz
	 1 : always bypass
 bit 15 :  System Momory Graphics PC133 Enable
*/

#define _SM 0x09C
/*
 SM System memory control register
*/

#define _GMCHCFG 0x050
/*
 GMCH Configuration Register
 APCONT 0x51 (>>8)
 DRP  0x52 (>>16)
 DRAMT is at 0x053 (last byte, so >>24)
*/

#define _DRP2 0x54

#define _AMTT 0x0BC
/*
 0x0BD LPTT (so>>8)
 0x0BE MCHCFG,   (so>>16)
*/

#define _CAPID 0x88


/* 
	-------------------- interesting bits
*/

#define AGP_133 (1<<31)
/* _CAPID */

#define SMG_PC133 (1<<(16+15))
#define BNR  (2<<16)
#define CPC  (1<<(16+11))
#define TLOCK (1<<(16+3))
#define SM   (1<<(16+13))
/* SM is a bit, _SM is a register */
/* _SMRAM (MISCC) */

#define FW   (1<<4)
/* _AGPCMD */

#define SBA  (1<<9)
/* _AGPCMD */

#define TDLLE (1<<15)
/* _SM */

#define CLT_SET  (1<<6)
#define DPCP_ALL (1<<3)
#define SMFS_133 (1<<2)
#define LMFS_133 (1<<4)
#define MAGWE_TS (1<<7)
/* _GMCHCFG */

#define HACQS      (1<<(3+24))   
#define DCT_79     (1<<(4+24))
#define CAS_2      (1<<(2+24))
#define RAS2CAS_2  (1<<(1+24))
#define RAS_2      (1<<24)
/* _GMCHCFG (DRAMT) */


#define AGP_33V (1<<(3+16))
/* _AMTT (GMCHCFG "2" ) */

#define GFX_MODE (1<<8)
/* _GMCHCFG (APCONT) */

#endif
